@@ -6,6 +6,8 @@ __author__ = 'https://github.com/akvilary'
 # default indentation for sql body of SqlSection
 DEFAULT_IND = 2
 
+DIALECT = 'PostgreSQL'
+
 # for filters
 AND_MODE = 'AND'
 OR_MODE = 'OR'
@@ -151,6 +153,7 @@ SQL_KEYWORDS = (
     'UNIQUE',
     'UNNEST',
     'UNTIL',
+    'UPDATE',
     'USER',
     'USING',
     'VACUUM',
