@@ -11,9 +11,15 @@ from .sql_val import SqlVal
 from .utils.classes.container_convertible import ContainerConvertible
 from .utils.classes.filter_operator_manager import FilterOperatorManager
 from .utils.classes.string_convertible import StringConvertible
+from .utils.classes.json_convertion_requier import JsonConvertionRequier
 
 
-class SqlFilter(FilterOperatorManager, StringConvertible, ContainerConvertible):
+class SqlFilter(
+    FilterOperatorManager,
+    StringConvertible,
+    JsonConvertionRequier,
+    ContainerConvertible,
+):
     """
     SqlFilter class is invented to build single sql keyword parameter faster.
     """
@@ -36,3 +42,8 @@ class SqlFilter(FilterOperatorManager, StringConvertible, ContainerConvertible):
         if self.key:
             return str(self.key) + '=' + str(SqlVal(self.value))
         return str(self.value)
+
+    def __as_json__(self):
+        if self.key:
+            return str(self.key) + '=' + SqlVal(self.value).__as_json__()
+        return str(self.value)
