@@ -4,8 +4,8 @@ from sqlconstructor import SqlPlaceholder
 
 @pytest.mark.SqlPlaceholder
 def test_add():
-    assert SqlPlaceholder('a') + 'b' == '$ab'
+    assert str(SqlPlaceholder('a') + 'b') == '$ab'
 
 @pytest.mark.SqlPlaceholder
 def test_radd():
-    assert 'b' + SqlPlaceholder('a') == 'b$a'
+    assert str('b' + SqlPlaceholder('a')) == 'b$a'
